---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Code Sample**

A "Minimal, Complete and Verifiable Example" will make it much easier for maintainers to help you:
<http://matthewrocklin.com/blog/work/2018/02/28/minimal-bug-reports>. I.e., this shouldn't rely upon a file on your local machine. Can you recreate this bug with a small dummy dataset of randomly generated `numpy`/`xarray` data?

```python
# Your code here
```

**Expected behavior**
A clear and concise description of what you expected to happen.

**Output of `climpred.show_versions()`**

<details>
# Paste the output here climpred.show_versions() here
</details>

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Additional context**
Add any other context about the problem here.
